import { restGet, restPost } from './restConsumer.js'

export async function login(user, pass, exp){
	return restPost("/login", {identifier: user, password: pass, expirationDate: exp});
}

/**
 * Register a user (tokenless)
 * 
 * @param data object containing info about the user
 *
 * - firstname
 * - lastname
 * - birthdate
 * - password
 * - mail
 * - address
 * - country
 * - cursus
 */
export async function register(firstname, lastname, birthDate, password, email, address, country, cursus){
	return restPost("/register", {
		firstname: firstname,
		lastname: lastname,
		birthDate: birthDate,
		password: password,
		email: email,
		address: address,
		country: country,
		cursus: cursus
	});
}

/**
 * Register a user (by secretary)
 * 
 * @param data object containing info about the user
 *
 * - firstname
 * - lastname
 * - birthdate
 * - password
 * - mail
 * - address
 * - country
 * - cursus
 *
 * PS: the password is not is not required as it is generated by the backend and sent to the user
 * by mail. it's up to the user to change it if he cares about security
 */
export async function createUser(firstname, lastname, birthDate, email, address, country, cursus, role){
	return restPost("/user", {
		firstname: firstname,
		lastname: lastname,
		birthDate: birthDate,
		password: password,
		email: email,
		address: address,
		country: country,
		cursus:cursus
	});
}

/**
 * get informations on a specific user.
 * Leaving the id empty will return the user's value based on his token
 * if the user is not authenticated. then an empty array should be returned
 */
export async function getUser(id){
	const endpoint = "/user" + id != null ? "/" + id : "";
	return restGet(endpoint);
}

/**
 * Reserved for secretary roles. Allow to list all user on the plateform
 */
export async function getAllUsers(){
	return restGet("/users");
}

